from regressionpack import *
#from .AbstractRegression import AbstractRegression
from .Linear import Linear
from .Polynomial import Polynomial
from .Exponential import Exponential
from .GenericCurveFit import GenericCurveFit
from .CosineFit import CosineFit
from .SystemIdentification import SystemIdentification
from .Gaussian import Gaussian
from .Ellipse import Ellipse
from .JonckheereTerpstra import JonckheereTerpstra